1.17.1 — Rucio 1.2 documentation

# 1.17.1

## General

### Features

- Core & Internals: Transparent list-replicas support of zip contents #1138

### Enhancements

- Consistency checks: Auditor is looking for site dumps in invalid locations #1268
- Core & Internals: closeness_sorter module seems to be dead code #320
- Infrastructure: add kubernetes config to repo #1226
- Infrastructure: docker builds fail with pip install error (pycurl/m2crypto) #1269
- Rebalancing: Uniformize the rebalancing scripts for Nuclei and T2 #1283
- Release management: Relax the dependency versions the pip-requires #1215

### Bugs

- Clients: REST/Client : set-metadata should raise DataIdentifierNotFound when the DID doesn’t exist #1272
- Core & Internals: Resurrect method doesn’t remove expired_at for deleted_dids #1276
- Life time model: End of life badly set for non-pledged endpoints #1240

## Clients

### Enhancements

- Clients: rucio download –archive_did should be renamed to –archive-did #1282

### Bugs

- Clients: findall with 2 arguments failing on SL6 #1288